# Converting Number To Persian Package

This package help to convert number into string as Persian numbering system.

#BASIC INFORMATION:

*Max integer input is upto 100 digits *For educational purpose and office purpose.

#Example:

from cntp import module

result = module.convert(123456)

print(res)  #output : یکصد و بیست و سه هزار و چهارصد و پنجاه و شش 